package cn.kdan.pdf.backend.core.service.impl;

import cn.kdan.pdf.backend.core.constant.ProviderConstant;
import cn.kdan.pdf.backend.core.enums.ProviderEnum;
import cn.kdan.pdf.backend.core.mapper.CancelMemberMapper;
import cn.kdan.pdf.backend.core.model.CancelMember;
import cn.kdan.pdf.backend.core.model.CancelMemberExample;
import cn.kdan.pdf.backend.core.model.Members;
import cn.kdan.pdf.backend.core.model.SocialAccounts;
import cn.kdan.pdf.backend.core.service.CancelMemberService;
import cn.kdan.pdf.backend.core.service.SocialAccountService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;
import org.springframework.util.StringUtils;
import utils.CommonUtils;

import javax.annotation.Resource;
import java.util.Date;
import java.util.List;

/**
 * @author sfq
 * @description
 */
@Slf4j
@Service
public class CancelMemberServiceImpl implements CancelMemberService {

    @Resource
    private SocialAccountService socialAccountService;
    @Resource
    private CancelMemberMapper cancelMemberMapper;

    @Override
    public void addCancelMember(Members members, String cancelReason) {
        // 插入注销账号记录,被绑定的账号都插入记录
        CancelMember cancelMember = new CancelMember();
        cancelMember.setId(CommonUtils.generateId());
        cancelMember.setPhone(members.getPhone());
        cancelMember.setEmail(members.getEmail());
        String memberId = members.getId();
        List<SocialAccounts> socialAccounts = socialAccountService.selectByMemberId(memberId);
        // 一个用户可能绑定多个第三方账号，所以需要遍历
        if(!CollectionUtils.isEmpty(socialAccounts)){
            for (SocialAccounts socialAccount : socialAccounts) {
                if(ProviderEnum.TENCENT.getValue().equals(socialAccount.getProvider())){
                    cancelMember.setTencent(socialAccount.getAccountId());
                }else{
                    cancelMember.setWechat(socialAccount.getAccountId());
                }
            }
        }
        cancelMember.setCancelReason(cancelReason);
        Date date = new Date();
        cancelMember.setCreatedAt(date);
        cancelMember.setUpdatedAt(date);
        cancelMemberMapper.insert(cancelMember);
    }

    @Override
    public boolean isCancelMember(String account, String provider) {
        CancelMemberExample example = new CancelMemberExample();
        CancelMemberExample.Criteria criteria = example.createCriteria();
        if(ProviderConstant.PHONE.equals(provider)){
            criteria.andPhoneEqualTo(account);
        }else if(ProviderConstant.EMAIL.equals(provider)){
            criteria.andEmailEqualTo(account);
        }else if (ProviderConstant.WECHAT.equals(provider)){
            criteria.andWechatEqualTo(account);
        }else{
            criteria.andTencentEqualTo(account);
        }
        List<CancelMember> cancelMembers = cancelMemberMapper.selectByExample(example);
        if(!CollectionUtils.isEmpty(cancelMembers)){
            return true;
        }
        return false;
    }
}
